Usage
as.receiver(x)
"plot"(x, add, pch, cex, col, bearings, ...)
"print"(x, ...)
"as.data.frame"(x, row.names = NULL,optional = FALSE, ...)
Arguments
x
An object inheriting the class data.frame or table containing the X and Y location of the receiver, the bearings of the transmitter signal, and the identification of the point groupings.
add
A logical specification for whether to plot locations onto an existing plot window.
pch
Either an integer specifying a symbol or a single character to be used as the default in plotting points.
cex
A numerical value giving the amount by which plotting locations should be magnified to the default.
col
A specification for the default plotting color.
bearings
A logical specification for whether azimuth bearings should be plotted alongside locations.
row.names
NULL or a character vector giving the row names for the data frame. Missing values are not allowed.
optional
Logical. If TRUE, setting row names and convering column names is optional.
...
Additional parameters to be passed to the generic function plot, print, and as.data.frame.