Usage
locate(x)
"plot"(x, add, errors, pch, cex, col, badcolor, ...)
"print"(x, ...)
"as.data.frame"(x, row.names=NULL, optional=FALSE, ...)
Arguments
x
An object inhering the class receiver containing the X and Y location of the receiver, the bearing of the transmitter signal, and the identification of the point groupings. If data inherits the class data.frame or table, it should contain these columns under the headings 'Easting', 'Northing','Bearing', and 'GID' respectively
add
A logical specification for whether to plot locations onto an existing plot window.
errors
A logical specification for whether error ellipses should be plotted alongside estimated locations.
pch
Either an integer specifying a symbol or a single character to be used as the default in plotting points.
cex
A numerical value giving the amount by which plotting locations should be magnified to the default.
col
A specification for the default plotting color.
badcolor
A logical specification for whether non-MLE-derived locations should be idenitfied.
row.names
NULL or a character vector giving the row names for the data frame. Missing values are not allowed.
optional
Logical. If TRUE, setting row names and convering column names is optional.
...
Additional parameters to be passed to the generic function plot, print, and as.data.frame.